@@ -2,8 +2,9 @@
 
 usage:
     ia tasks [--verbose] [--task=<task_id>...] [--get-task-log=<task_id>]
-             [--green-rows] [--blue-rows] [--red-rows]
+             [--green-rows] [--blue-rows] [--red-rows] [--parameter=<k:v>...]
     ia tasks [--verbose] <identifier>
+             [--green-rows] [--blue-rows] [--red-rows] [--parameter=<k:v>...]
     ia tasks --help
 
 options:
@@ -14,6 +15,7 @@ options:
     -g, --green-rows              Return information about tasks that have not run.
     -b, --blue-rows               Return information about running tasks.
     -r, --red-rows                Return information about tasks that have failed.
+    -p, --parameter=<k:v>...      Return tasks matching the given parameter.
 
 """
 import sys
@@ -21,12 +23,14 @@ import sys
 from docopt import docopt
 
 from internetarchive import Catalog, get_tasks
+from internetarchive.iacli.argparser import get_args_dict
 
 
 # ia_catalog()
 #_________________________________________________________________________________________
 def main(argv):
     args = docopt(__doc__, argv=argv)
+    params = get_args_dict(args['--parameter'])
 
     row_types = {
         -1: 'done',
@@ -36,17 +40,19 @@ def main(argv):
         9: 'brown',
     }
 
+    task_type = None
+    if args['--green-rows']:
+        task_type = 'green'
+    elif args['--blue-rows']:
+        task_type = 'blue'
+    elif args['--red-rows']:
+        task_type = 'red'
+
     try:
         if args['<identifier>']:
-            tasks = get_tasks(identifier=args['<identifier>'])
-        elif args['--green-rows']:
-            tasks = get_tasks(task_type='green')
-        elif args['--blue-rows']:
-            tasks = get_tasks(task_type='blue')
-        elif args['--red-rows']:
-            tasks = get_tasks(task_type='red')
+            tasks = get_tasks(identifier=args['<identifier>'], task_type=task_type, params=params)
         elif args['--get-task-log']:
-            task = get_tasks(task_ids=args['--get-task-log'])
+            task = get_tasks(task_ids=args['--get-task-log'], params=params)
             if task:
                 log = task[0].task_log()
                 sys.stdout.write(log)
@@ -56,8 +62,11 @@ def main(argv):
                 )
                 sys.exit(1)
             sys.exit(0)
+        elif args['--task']:
+            tasks = get_tasks(task_ids=args['--task'], params=params)
         else:
-            tasks = get_tasks(task_ids=args['--task'])
+            tasks = get_tasks(task_type=task_type, params=params)
+
         for t in tasks:
             task_info = [
                 t.identifier, t.task_id, t.server, t.time, t.command, 
