@@ -191,8 +191,9 @@ class Item(object):
 
     # download()
     # ____________________________________________________________________________________
-    def download(self, concurrent=False, source=None, formats=None, glob_pattern=None,
-                 dry_run=False, verbose=False, ignore_existing=False):
+    def download(self, concurrent=None, source=None, formats=None, glob_pattern=None,
+                 dry_run=None, verbose=None, ignore_existing=None, checksum=None,
+                 no_directory=None):
         """Download the entire item into the current working directory.
 
         :type concurrent: bool
@@ -212,10 +213,36 @@ class Item(object):
         :param ignore_existing: Overwrite local files if they already
                                 exist.
 
+        :type checksum: bool
+        :param checksum: Skip downloading file based on checksum.
+
+        :type no_directory: bool
+        :param no_directory: Download files to current working
+                             directory rather than creating an item
+                             directory.
+
         :rtype: bool
         :returns: True if if files have been downloaded successfully.
 
         """
+        concurrent = False if concurrent is None else concurrent
+        dry_run = False if dry_run is None else dry_run
+        verbose = False if verbose is None else verbose
+        ignore_existing = False if ignore_existing is None else ignore_existing
+        checksum = False if checksum is None else checksum
+        no_directory = False if no_directory is None else no_directory
+
+        if verbose:
+            sys.stdout.write('{0}:\n'.format(self.identifier))
+            if self._json.get('is_dark') is True:
+                sys.stdout.write(' skipping: item is dark.\n')
+                log.warning('Not downloading item {0}, '
+                            'item is dark'.format(self.identifier))
+            elif self.metadata == {}:
+                sys.stdout.write(' skipping: item does not exist.\n')
+                log.warning('Not downloading item {0}, '
+                            'item does not exist.'.format(self.identifier))
+
         if concurrent:
             try:
                 from gevent import monkey
@@ -235,28 +262,27 @@ class Item(object):
 
         files = self.iter_files()
         if source:
-            if type(source) == str:
-                source = [source]
-            files = [f for f in files if f.source in source]
+            files = self.get_files(source=source)
         if formats:
-            if type(formats) == str:
-                formats = [formats]
-            files = [f for f in files if f.format in formats]
+            files = self.get_files(formats=formats)
         if glob_pattern:
-            files = [f for f in files if fnmatch(f.name, glob_pattern)]
+            files = self.get_files(glob_pattern=glob_pattern)
 
+        if not files and verbose:
+            sys.stdout.write(' no matching files found, nothing downloaded.\n')
         for f in files:
             fname = f.name.encode('utf-8')
-            path = os.path.join(self.identifier, fname)
+            if no_directory:
+                path = fname
+            else:
+                path = os.path.join(self.identifier, fname)
             if dry_run:
                 sys.stdout.write(f.url + '\n')
                 continue
-            if verbose:
-                sys.stdout.write(' downloading: {0}\n'.format(fname))
             if concurrent:
-                pool.spawn(f.download, path, ignore_existing=ignore_existing)
+                pool.spawn(f.download, path, verbose, ignore_existing, checksum)
             else:
-                f.download(path, ignore_existing=ignore_existing)
+                f.download(path, verbose, ignore_existing, checksum)
         if concurrent:
             pool.join()
         return True
@@ -294,12 +320,13 @@ class Item(object):
         """
         access_key = self.session.access_key if not access_key else access_key
         secret_key = self.session.secret_key if not secret_key else secret_key
+        target = 'metadata' if target is None else target
 
         url = '{protocol}//archive.org/metadata/{identifier}'.format(**self.__dict__)
         request = iarequest.MetadataRequest(
             url=url,
             metadata=metadata,
-            source_metadata=self.__dict__.get(target, {}),
+            source_metadata=self._json.get(target.split('/')[0], {}),
             target=target,
             priority=priority,
             access_key=access_key,
@@ -334,7 +361,7 @@ class Item(object):
     def upload_file(self, body, key=None, metadata=None, headers=None,
                     access_key=None, secret_key=None, queue_derive=True,
                     ignore_preexisting_bucket=False, verbose=False, verify=True,
-                    checksum=False, delete=False, retries=0, retries_sleep=20,
+                    checksum=False, delete=False, retries=None, retries_sleep=None,
                     debug=False, **kwargs):
         """Upload a single file to an item. The item will be created
         if it does not exist.
@@ -394,15 +421,13 @@ class Item(object):
             True
 
         """
-
-        if headers is None:
-            headers = {}
-
-        if metadata is None:
-            metadata = {}
-
-        access_key = self.session.access_key if not access_key else access_key
-        secret_key = self.session.secret_key if not secret_key else secret_key
+        # Defaults for empty params.
+        headers = {} if headers is None else headers
+        metadata = {} if metadata is None else metadata
+        access_key = self.session.access_key if access_key is None else access_key
+        secret_key = self.session.secret_key if secret_key is None else secret_key
+        retries = 0 if retries is None else retries
+        retries_sleep = 30 if retries_sleep is None else retries_sleep
 
         if not hasattr(body, 'read'):
             body = open(body, 'rb')
@@ -661,6 +686,7 @@ class File(object):
         self.size = None
         self.source = None
         self.format = None
+        self.md5 = None
         for key in _file:
             setattr(self, key, _file[key])
         base_url = '{protocol}//archive.org/download/{identifier}'.format(**item.__dict__)
@@ -678,7 +704,7 @@ class File(object):
 
     # download()
     # ____________________________________________________________________________________
-    def download(self, file_path=None, ignore_existing=False):
+    def download(self, file_path=None, verbose=None, ignore_existing=None, checksum=None):
         """Download the file into the current working directory.
 
         :type file_path: str
@@ -686,11 +712,31 @@ class File(object):
 
         :type ignore_existing: bool
         :param ignore_existing: Overwrite local files if they already
-                                exist."""
-        file_path = self.name if not file_path else file_path
-        if os.path.exists(file_path) and not ignore_existing:
-            raise IOError('File already exists: {0}'.format(file_path))
+                                exist.
 
+        :type checksum: bool
+        :param checksum: Skip downloading file based on checksum.
+
+        """
+        verbose = False if verbose is None else verbose
+        ignore_existing = False if ignore_existing is None else ignore_existing
+        checksum = False if checksum is None else checksum
+
+        file_path = self.name if not file_path else file_path
+        if os.path.exists(file_path):
+            if ignore_existing is False and checksum is False:
+                raise IOError('file already downloaded: {0}'.format(file_path))
+            if checksum:
+                md5_sum = utils.get_md5(open(file_path))
+                if md5_sum == self.md5:
+                    log.info('not downloading file {0}, '
+                             'file already exists.'.format(file_path))
+                    if verbose:
+                        sys.stdout.write(' skipping {0}: already exists.\n'.format(file_path))
+                    return
+
+        if verbose:
+            sys.stdout.write(' downloading: {0}\n'.format(file_path))
         parent_dir = os.path.dirname(file_path)
         if parent_dir != '' and not os.path.exists(parent_dir):
             os.makedirs(parent_dir)
@@ -699,12 +745,15 @@ class File(object):
             response = self._item.http_session.get(self.url, stream=True)
             response.raise_for_status()
         except HTTPError as e:
-            raise HTTPError('Error downloading {0}, {1}'.format(self.url, e))
+            raise HTTPError('error downloading {0}, {1}'.format(self.url, e))
         with open(file_path, 'wb') as f:
             for chunk in response.iter_content(chunk_size=1024):
                 if chunk:
                     f.write(chunk)
                     f.flush()
+        log.info('downloaded {0}/{1} to {2}'.format(self.identifier,
+                                                    self.name.encode('utf-8'),
+                                                    file_path))
 
     # delete()
     # ____________________________________________________________________________________
